.. _api:

API reference
=============

In this section you will find detailed descriptions of the MetPyRad public interface.
It describes how it works and how to use it.
It assumes some understanding of the key concepts.

.. toctree::
    :maxdepth: 2
    :caption: API reference

    hidex300
